@@ -8,7 +8,8 @@
 #### Regression analysis with compositional data containing zero values
 #### Chilean journal of statistics 6(2): 47-57
 ################################
-alfaridge.tune <- function(y, x, M = 10, a = seq(-1, 1, by = 0.1), lambda = seq(0, 2, by = 0.1), mat = NULL, ncores = 1, graph = TRUE, col.nu = 15) {
+alfaridge.tune <- function(y, x, M = 10, a = seq(-1, 1, by = 0.1), lambda = seq(0, 2, by = 0.1), mat = NULL,
+                           ncores = 1, graph = TRUE, col.nu = 15) {
 
   if ( min(x) == 0 )  a <- a[a>0]  ## checks for zero values in the data.
   da <- length(a)
@@ -59,9 +60,10 @@ alfaridge.tune <- function(y, x, M = 10, a = seq(-1, 1, by = 0.1), lambda = seq(
   mean.mspe <- apply(mspe, 1:2, mean)
   best.par <- ( which(mean.mspe == min(mean.mspe), arr.ind = TRUE)[1, ] )
   opt.mspe <- mean.mspe[ best.par[1], best.par[2] ]
-  rownames(mean.mspe) <- a   
+  rownames(mean.mspe) <- a
   colnames(mspe) <- lambda
-  if ( graph )  filled.contour( a, lambda, mean.mspe, xlab = expression( paste(alpha, " values") ), ylab = expression( paste(lambda, " values") ) )
+  if ( graph )  filled.contour( a, lambda, mean.mspe, xlab = expression( paste(alpha, " values") ),
+                                ylab = expression( paste(lambda, " values") ), cex.lab = 1.3 )
 
   best.par <- c( a[ best.par[1] ], best.par[2] )
   names(best.par) <- c("alpha", "lambda")
